summaryrefslogtreecommitdiff
path: root/src/gui/widgets/tabs/setup_chat.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/widgets/tabs/setup_chat.cpp')
-rw-r--r--src/gui/widgets/tabs/setup_chat.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/gui/widgets/tabs/setup_chat.cpp b/src/gui/widgets/tabs/setup_chat.cpp
index 7ac53f38b..5973ae42b 100644
--- a/src/gui/widgets/tabs/setup_chat.cpp
+++ b/src/gui/widgets/tabs/setup_chat.cpp
@@ -1,10 +1,10 @@
/*
* The ManaPlus Client
* Copyright (C) 2009 The Mana World Development Team
* Copyright (C) 2009-2010 Andrei Karas
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -180,9 +180,9 @@ Setup_Chat::Setup_Chat(const Widget2 *const widget) :
// TRANSLATORS: settings option
new SetupItemCheckBox(_("Hide shop messages"),
// TRANSLATORS: settings description
- _("If this setting enabled, no messages related to built-in ManaPlus "
+ _("If this setting enabled, no messages related to built-in ManaVerse "
"shop will be displayed in chat. Disable this setting if you want "
- "to see shop-related messages.\n\nNote: technically, ManaPlus shop "
+ "to see shop-related messages.\n\nNote: technically, ManaVerse shop "
"implemented as usual private messages with special content. If you "
"disable this setting, you will be able to see these messages and get "
"idea when other players are looking at your shop."),
@@ -1,10 +1,10 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2009 The Mana World Development Team
* Copyright (C) 2009-2010 Andrei Karas
@@ -1,10 +1,10 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify